IspInfo class

Model for the Isp Information returned by the API

Constructors

IspInfo({String? isp, String? organization, String? asn})
The IspInfo constructor is used to create a new instance of the IspInfo class.
const
IspInfo.fromJson(Map<String, dynamic> json)
The IspInfo.fromJson factory constructor is used to create a new instance of the IspInfo class from a JSON object.
factory

Properties

asn String?
The ASN of the IP address
final
hashCode int
The hash code for this object.
no setterinherited
isp String?
The ISP of the IP address
final
organization String?
The organization of the IP address
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited