dart_ipquery library
Classes
- IpInfo
- Model for the IP Information returned by the API
- IpQueryClient
- The IpQueryClient class is used to query the IPQuery API.
- IspInfo
- Model for the Isp Information returned by the API
- Location
- Model for the Location Information returned by the API
- Risk
- Model for the Risk Information returned by the API