Location class
Model for the Location Information returned by the API
Constructors
- Location({String? country, String? countryCode, String? state, String? city, String? zipCode, double? lat, double? lon, String? timezone, String? localTime})
-
The Location constructor is used to create a new instance of the Location class.
const
-
Location.fromJson(Map<
String, dynamic> json) -
The Location.fromJson factory constructor is used to create a new instance of the Location class from a JSON object.
factory
Properties
- city → String?
-
The city of the IP address
final
- country → String?
-
The country of the IP address
final
- countryCode → String?
-
The country code of the IP address
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lat → double?
-
The latitude of the IP address
final
- localTime → String?
-
The local time of the IP address
final
- lon → double?
-
The longitude of the IP address
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
The state of the IP address
final
- timezone → String?
-
The timezone of the IP address
final
- zipCode → String?
-
The zip code of the IP address
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited